aboutsummaryrefslogtreecommitdiffstats
path: root/os/io/templates/adc_lld.h
diff options
context:
space:
mode:
authorgdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2009-11-06 16:33:03 +0000
committergdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2009-11-06 16:33:03 +0000
commit0521c90a445af93ea53f7d0e1847fa8a12a9c423 (patch)
tree93d57d723868a8d415c4ab981e977b20b8ec8977 /os/io/templates/adc_lld.h
parentaf65d01d0a76f9a0593dd36326c100d4f26f4c0d (diff)
downloadChibiOS-0521c90a445af93ea53f7d0e1847fa8a12a9c423.tar.gz
ChibiOS-0521c90a445af93ea53f7d0e1847fa8a12a9c423.tar.bz2
ChibiOS-0521c90a445af93ea53f7d0e1847fa8a12a9c423.zip
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@1270 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'os/io/templates/adc_lld.h')
-rw-r--r--os/io/templates/adc_lld.h77
1 files changed, 76 insertions, 1 deletions
diff --git a/os/io/templates/adc_lld.h b/os/io/templates/adc_lld.h
index ab8a48bf9..6fde9c181 100644
--- a/os/io/templates/adc_lld.h
+++ b/os/io/templates/adc_lld.h
@@ -32,10 +32,85 @@
/*===========================================================================*/
/*===========================================================================*/
+/* Driver constants. */
+/*===========================================================================*/
+
+/**
+ * @brief Linear buffering mode.
+ * @details In the linear buffering mode the buffer is filled one time and
+ * then the operation automatically stops.
+ */
+#define ADC_GROUP_BUFFER_LINEAR 0
+
+/**
+ * @brief Circular buffering mode.
+ * @details In the circular buffering mode the buffer is filled one time and
+ * then the operation automatically starts again.
+ */
+#define ADC_GROUP_BUFFER_CIRCULAR 1
+
+/*===========================================================================*/
/* Driver data structures and types. */
/*===========================================================================*/
/**
+ * @brief ADC sample data type.
+ */
+typedef uint16_t adcsample_t;
+
+/**
+ * @brief Channels number in a conversion group.
+ */
+typedef uint16_t adc_channels_num_t;
+
+/**
+ * @brief Samples buffer depth.
+ */
+typedef uint16_t adc_buffer_depth_t;
+
+/**
+ * @brief ADC notification callback type.
+ * @param[in] buffer pointer to the most recent samples data
+ * @param[in] n number of buffer rows available starting from @p buffer
+ */
+typedef void (*adccallback_t)(adcsample_t *buffer,
+ adc_buffer_depth_t n);
+
+/**
+ * @brief Conversion group configuration structure.
+ * @details This implementation-dependent structure describes a conversion
+ * operation.
+ */
+typedef struct {
+ /**
+ * @brief Group mode flags.
+ */
+ uint_least8_t acg_mode;
+
+ /**
+ * @brief Number of the analog channels belonging to the conversion group.
+ */
+ adc_channels_num_t acg_num_channels;
+
+ /**
+ * @brief Samples buffer depth.
+ * @note The buffer depth must be an even number or one. The 50% callback
+ * behavior for buffers with odd depth is unspecified.
+ */
+ adc_buffer_depth_t acg_buffer_depth;
+
+ /**
+ * @brief Data streaming callback.
+ * @details This callback is invoked at 50% and 100% buffer fill level in
+ * order to allow realtime processing of the conversion results
+ * when the circular buffer mode is selected.
+ * @note The 50% callback is only invoked if @p acg_num_samples is greater
+ * than 1.
+ */
+ adccallback_t acg_callback;
+} ADCConversionGroup;
+
+/**
* @brief Driver configuration structure.
*/
typedef struct {
@@ -43,7 +118,7 @@ typedef struct {
} ADCConfig;
/**
* @brief Structure representing a MAC driver.
*/
typedef struct {
/**
@@ -43,7 +118,7 @@ typedef struct {
} ADCConfig;
/**
- * @brief Structure representing a MAC driver.
+ * @brief Structure representing an ADC driver.
*/
typedef struct {